## Title：MarsGT:Multi-omics data analysis for rare population inference using single-cell graph transformer
**Note: This project is for internal testing purposes only. Do not use it in a production environment.**

DeepMARS, for rare cell identification from matched scRNA-seq (snRNA-seq) and scATAC-seq (snATAC-seq),includes genes, enhancers, and cells in a heterogeneous graph to simultaneously identify major cell clusters and rare cell clusters based on eRegulon.
## Installation

### System Requirements

* Python 3.8.0 or higher

### Installation Steps
* Install the required dependencies using pip:
```bash
pip install -r requirements.txt
```
* use pip to install MarsGT:
```bash
pip install MarsGT
```
